==================
Installation guide
==================

Melexis Warnings plugin is packaged with pip, but once installed it offers
direct command line invocation (no need to run python infront). That is why
installation is as simple as:

.. code-block:: bash

    # Python2
    pip2 install mlx.warnings

    # Python3
    pip3 install mlx.warnings

    # Install latest and greatest
    pip install https://github.com/melexis/warnings-plugin/archive/master.zip

So far we are not aware of any problems with installation of the plugin, but in
case you have any please open the Issue.

